@@ -1,4 +1,4 @@
-// Copyright (c) 2018-2019 Intel Corporation
+// Copyright (c) 2018-2020 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -28,6 +28,7 @@
 #include "mfx_common_decode_int.h"
 
 #ifdef MFX_ENABLE_SW_FALLBACK
+#include <ippcore.h> // for MfxIppInit()
 #include "mfx_mjpeg_task.h"
 #include "umc_mjpeg_mfx_decode.h"
 #include "mfx_thread_task.h"
@@ -37,7 +38,7 @@
 
 #include "umc_jpeg_frame_constructor.h"
 #include "umc_mjpeg_mfx_decode_hw.h"
-
+#include "mfx_session.h"
 
 // Declare skipping constants
 enum
@@ -409,7 +410,12 @@ mfxStatus VideoDECODEMJPEG::DecodeHeader(VideoCORE *core, mfxBitstream *bs, mfxV
 {
     MFX_CHECK_NULL_PTR2(bs, par);
 
-    MFX_SAFE_CALL(CheckBitstream(bs));
+    mfxStatus sts = CheckBitstream(bs);
+    if (sts != MFX_ERR_NONE)
+    {
+        MFX_CHECK_INIT(sts == MFX_ERR_NULL_PTR);
+        MFX_RETURN(MFX_ERR_NULL_PTR);
+    }
 
     MFXMediaDataAdapter in(bs);
 
@@ -429,39 +435,29 @@ mfxStatus VideoDECODEMJPEG::DecodeHeader(VideoCORE *core, mfxBitstream *bs, mfxV
     umcVideoParams.lpMemoryAllocator = &tempAllocator;
 
     UMC::Status umcRes = decoder.Init(&umcVideoParams);
-    if (umcRes != UMC::UMC_OK)
-    {
-        return ConvertUMCStatusToMfx(umcRes);
-    }
+    MFX_CHECK_INIT(umcRes == UMC::UMC_OK);
 
     umcRes = decoder.DecodeHeader(&in);
 
     in.Save(bs);
 
-    if (umcRes == UMC::UMC_ERR_NOT_ENOUGH_DATA)
-        return MFX_ERR_MORE_DATA;
-
-    if (umcRes != UMC::UMC_OK)
-        return ConvertUMCStatusToMfx(umcRes);
+    MFX_CHECK_INIT(umcRes == UMC::UMC_OK);
 
     mfxVideoParam temp;
 
     umcRes = decoder.FillVideoParam(&temp, false);
-    if (umcRes != UMC::UMC_OK)
-        return ConvertUMCStatusToMfx(umcRes);
+    MFX_CHECK_INIT(umcRes == UMC::UMC_OK);
 
     if(jpegQT)
     {
         umcRes = decoder.FillQuantTableExtBuf(jpegQT);
-        if (umcRes != UMC::UMC_OK)
-            return ConvertUMCStatusToMfx(umcRes);
+        MFX_CHECK_INIT(umcRes == UMC::UMC_OK);
     }
 
     if(jpegHT)
     {
         umcRes = decoder.FillHuffmanTableExtBuf(jpegHT);
-        if (umcRes != UMC::UMC_OK)
-            return ConvertUMCStatusToMfx(umcRes);
+        MFX_CHECK_INIT(umcRes == UMC::UMC_OK);
     }
 
     decoder.Close();
@@ -482,12 +478,6 @@ mfxStatus VideoDECODEMJPEG::QueryIOSurf(VideoCORE *core, mfxVideoParam *par, mfx
 
     eMFXPlatform platform = MFX_JPEG_Utility::GetPlatform(core, par);
 
-    eMFXHWType type = MFX_HW_UNKNOWN;
-    if (platform == MFX_PLATFORM_HARDWARE)
-    {
-        type = core->GetHWType();
-    }
-
     mfxVideoParam params = *par;
     bool isNeedChangeVideoParamWarning = IsNeedChangeVideoParam(&params);
 
@@ -597,12 +587,6 @@ mfxStatus VideoDECODEMJPEG::QueryIOSurfInternal(VideoCORE *core, mfxVideoParam *
     }
     else
     {
-        eMFXHWType type = MFX_HW_UNKNOWN;
-        if (platform == MFX_PLATFORM_HARDWARE)
-        {
-            type = core->GetHWType();
-        }
-
         bool needVpp = false;
         if(par->mfx.FrameInfo.PicStruct == MFX_PICSTRUCT_FIELD_TFF ||
            par->mfx.FrameInfo.PicStruct == MFX_PICSTRUCT_FIELD_BFF)
@@ -663,7 +647,7 @@ mfxStatus VideoDECODEMJPEG::DecodeFrameCheck(mfxBitstream *bs, mfxFrameSurface1
     // It can be useful to run threads right after first frame receive
     MFX_SAFE_CALL(DecodeFrameCheck(bs, surface_work, surface_out));
 
-    UMC::FrameData *dst;
+    UMC::FrameData *dst = nullptr;
     MFX_SAFE_CALL(decoder->AllocateFrameData(dst));
 
     {
@@ -777,6 +761,11 @@ mfxStatus VideoDECODEMJPEG::DecodeFrameCheck(mfxBitstream *bs, mfxFrameSurface1
     mfxU32 numPic = 0;
     mfxU32 picToCollect = (MFX_PICSTRUCT_PROGRESSIVE == m_vPar.mfx.FrameInfo.PicStruct) ? 1 : 2;
 
+    //gpu session priority 
+    UMC::VideoDecoderParams* videoDecoderParams = &(decoder->umcVideoParams);
+    if (videoDecoderParams != nullptr && videoDecoderParams->pVideoAccelerator != nullptr)
+        videoDecoderParams->pVideoAccelerator->m_ContextPriority = m_core->GetSession()->m_priority;
+
     do
     {
         MFXMediaDataAdapter src(bs);
@@ -851,7 +840,21 @@ mfxStatus VideoDECODEMJPEG::DecodeFrameCheck(mfxBitstream *bs, mfxFrameSurface1
         m_isHeaderFound = false;
         m_isHeaderParsed = false;
 
-        MFX_SAFE_CALL(decoder->AddPicture(pSrcData, numPic));
+        try
+        {
+            MFX_SAFE_CALL(decoder->AddPicture(pSrcData, numPic));
+        }
+        catch(const UMC::eUMC_Status& sts)
+        {
+            if(sts == UMC::UMC_ERR_INVALID_STREAM)
+            {
+                continue;
+            }
+            else
+            {
+                return ConvertUMCStatusToMfx(sts);
+            }
+        }
     // make sure, that we collected BOTH fields
     } while (picToCollect > numPic);
 
@@ -1054,11 +1057,13 @@ bool MFX_JPEG_Utility::IsNeedPartialAcceleration(VideoCORE * core, mfxVideoParam
         switch (par->mfx.FrameInfo.FourCC)
         {
             case MFX_FOURCC_NV12:
-                if (par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_YCbCr &&
+                if  ((par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_YCbCr &&
                         (par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV420  ||
                          par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV422H ||
                          par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV422V ||
-                         par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV444 ))
+                         par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV444 )) ||
+                    (par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_RGB &&
+                         par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV444))
                     return false;
                 else
                     return true;
@@ -1329,8 +1334,7 @@ mfxStatus MFX_JPEG_Utility::Query(VideoCORE *core, mfxVideoParam *in, mfxVideoPa
             const short unsigned MHW_SFC_MAX_HEIGHT        = 4096;
             const short unsigned MHW_SFC_MAX_WIDTH         = 4096;
 
-            if ( (MFX_HW_VAAPI == (core->GetVAType())) &&
-                 (MFX_PICSTRUCT_PROGRESSIVE == in->mfx.FrameInfo.PicStruct) &&
+            if ( (MFX_PICSTRUCT_PROGRESSIVE == in->mfx.FrameInfo.PicStruct) &&
                  (in->IOPattern & MFX_IOPATTERN_OUT_VIDEO_MEMORY) &&
                  // FtrSFCPipe is not supported on BDW, and there is a known issue on SCL
                  (core->GetHWType() > MFX_HW_SCL) &&
@@ -1771,6 +1775,14 @@ void VideoDECODEMJPEGBase_HW::AdjustFourCC(mfxFrameInfo *requestFrameInfo, const
             break;
         }
     }
+    else if(info->JPEGColorFormat == MFX_JPEG_COLORFORMAT_RGB)
+    {
+        if(info->JPEGChromaFormat == MFX_CHROMAFORMAT_YUV444 && info->Rotation == MFX_ROTATION_0)
+        {
+            requestFrameInfo->FourCC = MFX_FOURCC_RGBP;
+            *needVpp = true;
+        }
+    }
 }
 
 
@@ -2019,6 +2031,9 @@ VideoDECODEMJPEGBase_SW::VideoDECODEMJPEGBase_SW()
 
 mfxStatus VideoDECODEMJPEGBase_SW::Init(mfxVideoParam *decPar, mfxFrameAllocRequest *request, mfxFrameAllocResponse *response, mfxFrameAllocRequest *, bool isUseExternalFrames, VideoCORE *core)
 {
+    auto ippSt = MfxIppInit();
+    MFX_CHECK(ippSt == ippStsNoErr, MFX_ERR_UNSUPPORTED);
+
     UMC::Status umcSts = m_FrameAllocator->InitMfx(0, core, decPar, request, response, isUseExternalFrames, true);
     MFX_CHECK(umcSts == UMC::UMC_OK, MFX_ERR_MEMORY_ALLOC);
 
