@@ -24,6 +24,7 @@
 #include "mfx_vp9_encode_hw_vaapi.h"
 #include "mfx_common_int.h"
 #include <map>
+#include "mfx_session.h"
 
 namespace MfxHwVP9Encode
 {
@@ -575,9 +576,9 @@ VAAPIEncoder::VAAPIEncoder()
 , m_vaConfig(VA_INVALID_ID)
 , m_sps()
 , m_pps()
-, m_tempLayers()
 , m_vaBrcPar()
 , m_vaFrameRate()
+, m_priorityBuffer()
 , m_seqParam()
 , m_spsBufferId(VA_INVALID_ID)
 , m_ppsBufferId(VA_INVALID_ID)
@@ -587,6 +588,7 @@ VAAPIEncoder::VAAPIEncoder()
 , m_qualityLevelBufferId(VA_INVALID_ID)
 , m_packedHeaderParameterBufferId(VA_INVALID_ID)
 , m_packedHeaderDataBufferId(VA_INVALID_ID)
+, m_priorityBufferId(VA_INVALID_ID)
 , m_tempLayersBufferId(VA_INVALID_ID)
 , m_tempLayersParamsReset(false)
 , m_width(0)
@@ -594,6 +596,7 @@ VAAPIEncoder::VAAPIEncoder()
 , m_isBrcResetRequired(false)
 , m_caps()
 , m_platform()
+, m_MaxContextPriority(0)
 {
 } // VAAPIEncoder::VAAPIEncoder(VideoCORE* core)
 
@@ -686,6 +689,7 @@ mfxStatus VAAPIEncoder::CreateAuxilliaryDevice(
         VAConfigAttribEncMacroblockInfo,
         VAConfigAttribEncMaxRefFrames,
         VAConfigAttribEncSkipFrame,
+        VAConfigAttribContextPriority
     };
     std::vector<VAConfigAttrib> attrs;
 
@@ -766,6 +770,9 @@ mfxStatus VAAPIEncoder::CreateAuxilliaryDevice(
         m_caps.BRCReset = attrs[idx_map[VAConfigAttribProcessingRate]].value == VA_PROCESSING_RATE_ENCODE;
     }
 
+    if (attrs[ idx_map[VAConfigAttribContextPriority] ].value != VA_ATTRIB_NOT_SUPPORTED)
+        m_MaxContextPriority = attrs[ idx_map[VAConfigAttribContextPriority] ].value;
+
     HardcodeCaps(m_caps, m_platform);
 
     return MFX_ERR_NONE;
@@ -1012,13 +1019,6 @@ mfxStatus VAAPIEncoder::Register(mfxFrameAllocResponse& response, D3DDDIFORMAT t
 } // mfxStatus VAAPIEncoder::Register(mfxFrameAllocResponse& response, D3DDDIFORMAT type)
 
 
-mfxStatus VAAPIEncoder::Register(mfxMemId /*memId*/, D3DDDIFORMAT /*type*/)
-{
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_HOTSPOTS, "Register");
-    return MFX_ERR_UNSUPPORTED;
-
-} // mfxStatus VAAPIEncoder::Register(mfxMemId memId, D3DDDIFORMAT type)
-
 mfxStatus VAAPIEncoder::Execute(
     Task const & task,
     mfxHDLPair pair)
@@ -1189,6 +1189,41 @@ mfxStatus VAAPIEncoder::Execute(
 
         // 12. quality level
         configBuffers.push_back(m_qualityLevelBufferId);
+
+        // 13. Gpu Priority
+        if(m_MaxContextPriority)
+        {
+            mfxPriority contextPriority = m_pmfxCore->GetSession()->m_priority;
+            memset(&m_priorityBuffer, 0, sizeof(VAContextParameterUpdateBuffer));
+            m_priorityBuffer.flags.bits.context_priority_update = 1;   //need to set by parameter
+
+            if(contextPriority == MFX_PRIORITY_LOW)
+            {
+                m_priorityBuffer.context_priority.bits.priority = 0;
+            }
+            else if (contextPriority == MFX_PRIORITY_HIGH)
+            {
+                m_priorityBuffer.context_priority.bits.priority = m_MaxContextPriority;
+            }
+            else
+            {
+                m_priorityBuffer.context_priority.bits.priority = m_MaxContextPriority/2;
+            }
+
+            sts = CheckAndDestroyVAbuffer(m_vaDisplay, m_priorityBufferId);
+            MFX_CHECK_STS(sts);
+
+            vaSts = vaCreateBuffer(m_vaDisplay,
+                                   m_vaContextEncode,
+                                   VAContextParameterUpdateBufferType,
+                                   sizeof(m_priorityBuffer),
+                                   1,
+                                   &m_priorityBuffer,
+                                   &m_priorityBufferId);
+            MFX_CHECK_WITH_ASSERT(VA_STATUS_SUCCESS == vaSts, MFX_ERR_DEVICE_FAILED);
+
+            configBuffers.push_back(m_priorityBufferId);
+	}
     }
 
     //------------------------------------------------------------------
@@ -1371,6 +1406,12 @@ mfxStatus VAAPIEncoder::Destroy()
     sts = CheckAndDestroyVAbuffer(m_vaDisplay, m_tempLayersBufferId);
     std::ignore = MFX_STS_TRACE(sts);
 
+    if(m_MaxContextPriority)
+    {
+        sts = CheckAndDestroyVAbuffer(m_vaDisplay, m_priorityBufferId);
+        std::ignore = MFX_STS_TRACE(sts);
+    }
+
     for (VABufferID& id : m_frameRateBufferIds)
     {
         sts = CheckAndDestroyVAbuffer(m_vaDisplay, id);
